@@ -1,12 +1,19 @@
 """App Settings"""
 
+# Standard Library
+import logging
+
 # Django
 from django.conf import settings
 
+logger = logging.getLogger(__name__)
+
 # Janice API Configuration
 AAPAYOUT_JANICE_API_KEY = getattr(settings, "AAPAYOUT_JANICE_API_KEY", "")
-# Market ID (integer): 2=Jita, 1=Amarr, etc. See https://janice.e-351.com/api/rest/v2/markets
-AAPAYOUT_JANICE_MARKET = getattr(settings, "AAPAYOUT_JANICE_MARKET", 2)  # Default: Jita
+# Market ID (integer): 2=Jita, 1=Amarr, 3=Dodixie, 4=Rens, 5=Hek
+# The Janice API requires integer market IDs, not string names
+AAPAYOUT_JANICE_MARKET = getattr(settings, "AAPAYOUT_JANICE_MARKET", 2)  # Default: 2 (Jita)
+
 AAPAYOUT_JANICE_PRICE_TYPE = getattr(settings, "AAPAYOUT_JANICE_PRICE_TYPE", "buy")
 AAPAYOUT_JANICE_TIMEOUT = getattr(settings, "AAPAYOUT_JANICE_TIMEOUT", 30)
 AAPAYOUT_JANICE_CACHE_HOURS = getattr(settings, "AAPAYOUT_JANICE_CACHE_HOURS", 1)
@@ -14,6 +21,7 @@ AAPAYOUT_JANICE_CACHE_HOURS = getattr(settings, "AAPAYOUT_JANICE_CACHE_HOURS", 1
 # Payout Configuration
 AAPAYOUT_CORP_SHARE_PERCENTAGE = getattr(settings, "AAPAYOUT_CORP_SHARE_PERCENTAGE", 10)
 AAPAYOUT_MINIMUM_PAYOUT = getattr(settings, "AAPAYOUT_MINIMUM_PAYOUT", 1000000)
+AAPAYOUT_MINIMUM_PER_PARTICIPANT = getattr(settings, "AAPAYOUT_MINIMUM_PER_PARTICIPANT", 100000000)  # 100M ISK
 AAPAYOUT_REQUIRE_APPROVAL = getattr(settings, "AAPAYOUT_REQUIRE_APPROVAL", True)
 
 # Holding Corporation Configuration
