@@ -8,7 +8,7 @@ from django.core.exceptions import ValidationError
 
 # AA Payout
 from aapayout import constants
-from aapayout.models import Fleet, FleetParticipant, LootItem, LootPool
+from aapayout.models import Fleet, FleetParticipant, LootPool
 
 
 class FleetCreateForm(forms.ModelForm):
@@ -21,7 +21,7 @@ class FleetCreateForm(forms.ModelForm):
             "name": forms.TextInput(
                 attrs={
                     "class": "form-control",
-                    "placeholder": "e.g., Wormhole Gank Fleet",
+                    "placeholder": "e.g., Wormhole Gank Payout",
                 }
             ),
             "battle_report": forms.URLInput(
@@ -34,7 +34,7 @@ class FleetCreateForm(forms.ModelForm):
                 attrs={
                     "class": "form-control",
                     "rows": 3,
-                    "placeholder": "Additional notes about the fleet (optional)",
+                    "placeholder": "Additional notes about the payout (optional)",
                 }
             ),
         }
@@ -87,9 +87,17 @@ class ParticipantAddForm(forms.ModelForm):
         help_text="Type to search for characters in the database",
     )
 
+    is_scout = forms.BooleanField(
+        required=False,
+        initial=False,
+        widget=forms.CheckboxInput(attrs={"class": "form-check-input", "id": "id_is_scout"}),
+        label="Mark as Scout",
+        help_text="Scouts receive +10% bonus payout",
+    )
+
     class Meta:
         model = FleetParticipant
-        fields = ["role"]
+        fields = ["role", "is_scout"]
         widgets = {
             "role": forms.Select(attrs={"class": "form-select"}),
         }
@@ -98,9 +106,16 @@ class ParticipantAddForm(forms.ModelForm):
 class ParticipantEditForm(forms.ModelForm):
     """Form for editing a fleet participant"""
 
+    is_scout = forms.BooleanField(
+        required=False,
+        widget=forms.CheckboxInput(attrs={"class": "form-check-input"}),
+        label="Mark as Scout",
+        help_text="Scouts receive +10% bonus payout",
+    )
+
     class Meta:
         model = FleetParticipant
-        fields = ["role", "joined_at", "left_at", "notes"]
+        fields = ["role", "is_scout", "joined_at", "left_at", "notes"]
         widgets = {
             "role": forms.Select(attrs={"class": "form-select"}),
             "joined_at": forms.DateTimeInput(
@@ -139,7 +154,7 @@ class LootPoolCreateForm(forms.ModelForm):
 
     class Meta:
         model = LootPool
-        fields = ["raw_loot_text", "pricing_method"]
+        fields = ["raw_loot_text", "pricing_method", "scout_bonus_percentage"]
         widgets = {
             "raw_loot_text": forms.Textarea(
                 attrs={
@@ -152,9 +167,20 @@ class LootPoolCreateForm(forms.ModelForm):
                 }
             ),
             "pricing_method": forms.Select(attrs={"class": "form-select"}),
+            "scout_bonus_percentage": forms.NumberInput(
+                attrs={
+                    "class": "form-range",
+                    "type": "range",
+                    "min": "0",
+                    "max": "100",
+                    "step": "10",
+                    "id": "scout-bonus-slider-create",
+                }
+            ),
         }
         help_texts = {
             "raw_loot_text": "Paste items directly from EVE client inventory",
+            "scout_bonus_percentage": "Percentage bonus for scouts (0-100%)",
         }
 
     def clean_raw_loot_text(self):
@@ -164,37 +190,45 @@ class LootPoolCreateForm(forms.ModelForm):
         return loot_text.strip()
 
 
-class LootItemEditForm(forms.ModelForm):
-    """Form for editing individual loot item prices"""
+class LootPoolEditForm(forms.ModelForm):
+    """Form for editing a loot pool's raw text and settings"""
 
     class Meta:
-        model = LootItem
-        fields = ["unit_price", "notes"]
+        model = LootPool
+        fields = ["raw_loot_text", "pricing_method", "scout_bonus_percentage"]
         widgets = {
-            "unit_price": forms.NumberInput(
+            "raw_loot_text": forms.Textarea(
                 attrs={
-                    "class": "form-control",
-                    "min": "0",
-                    "step": "0.01",
+                    "class": "form-control font-monospace",
+                    "rows": 10,
+                    "placeholder": (
+                        "Paste loot from EVE client here...\n\n"
+                        "Example:\nCompressed Arkonor\t1000\nCompressed Bistot\t500"
+                    ),
                 }
             ),
-            "notes": forms.Textarea(
+            "pricing_method": forms.Select(attrs={"class": "form-select"}),
+            "scout_bonus_percentage": forms.NumberInput(
                 attrs={
-                    "class": "form-control",
-                    "rows": 2,
-                    "placeholder": "Reason for manual override (optional)",
+                    "class": "form-range",
+                    "type": "range",
+                    "min": "0",
+                    "max": "100",
+                    "step": "10",
+                    "id": "scout-bonus-slider-edit",
                 }
             ),
         }
         help_texts = {
-            "unit_price": "Price per unit in ISK",
+            "raw_loot_text": "Paste items directly from EVE client inventory",
+            "scout_bonus_percentage": "Percentage bonus for scouts (0-100%)",
         }
 
-    def clean_unit_price(self):
-        price = self.cleaned_data.get("unit_price")
-        if price < 0:
-            raise ValidationError("Price cannot be negative")
-        return price
+    def clean_raw_loot_text(self):
+        loot_text = self.cleaned_data.get("raw_loot_text", "")
+        if not loot_text or not loot_text.strip():
+            raise ValidationError("Loot text cannot be empty")
+        return loot_text.strip()
 
 
 class LootPoolApproveForm(forms.Form):
