@@ -58,11 +58,26 @@ class Fleet(models.Model):
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
 
+    # Finalization tracking
+    finalized = models.BooleanField(
+        default=False, help_text="Whether this fleet has been finalized (triggers wallet verification)"
+    )
+    finalized_at = models.DateTimeField(null=True, blank=True, help_text="When this fleet was finalized")
+    finalized_by = models.ForeignKey(
+        User,
+        on_delete=models.SET_NULL,
+        null=True,
+        blank=True,
+        related_name="finalized_fleets",
+        help_text="User who finalized this fleet",
+    )
+
     class Meta:
         ordering = ["-fleet_time"]
         indexes = [
             models.Index(fields=["-fleet_time"]),
             models.Index(fields=["fleet_commander", "status"]),
+            models.Index(fields=["finalized"]),
         ]
 
     def __str__(self):
@@ -135,6 +150,19 @@ class FleetParticipant(models.Model):
     def __str__(self):
         return f"{self.character.name} - {self.fleet.name}"
 
+    def save(self, *args, **kwargs):
+        """
+        Auto-sync is_scout with role for consistency.
+        If role is set to 'scout', ensure is_scout is True.
+
+        Note: This sync is one-way only - is_scout will not be cleared if role
+        changes away from scout. Additionally, is_scout can be set manually
+        independent of role, allowing intentional overrides.
+        """
+        if self.role == constants.ROLE_SCOUT:
+            self.is_scout = True
+        super().save(*args, **kwargs)
+
     @property
     def is_active(self):
         """Check if participant is still active in fleet"""
@@ -183,6 +211,12 @@ class LootPool(models.Model):
         default=0,
         help_text="Total participant share amount in ISK",
     )
+    scout_bonus_percentage = models.DecimalField(
+        max_digits=5,
+        decimal_places=2,
+        default=10,
+        help_text="Scout bonus percentage (default: 10%)",
+    )
     janice_appraisal_code = models.CharField(max_length=50, blank=True, help_text="Janice appraisal code for linking")
     valued_at = models.DateTimeField(null=True, blank=True, help_text="Time when loot was valued")
     approved_by = models.ForeignKey(
