@@ -7,6 +7,7 @@ Documentation: https://janice.e-351.com/api/rest/docs/index.html
 
 # Standard Library
 import logging
+import re
 from decimal import Decimal
 from typing import Dict
 
@@ -25,6 +26,48 @@ logger = logging.getLogger(__name__)
 JANICE_API_URL = "https://janice.e-351.com/api/rest/v2"
 
 
+def normalize_loot_text(loot_text: str) -> str:
+    """
+    Normalize loot text to ensure proper formatting for Janice API.
+
+    EVE client copy format uses tabs between item name and quantity (e.g., "Orca\t2").
+    Users may manually type space-separated input (e.g., "Orca 2").
+    This function converts space-separated format to tab-separated.
+
+    Args:
+        loot_text: Raw loot text (may be space or tab separated)
+
+    Returns:
+        Normalized loot text with tab separators
+    """
+    lines = []
+    for line in loot_text.strip().splitlines():
+        line = line.strip()
+        if not line:
+            continue
+
+        # If line already has a tab, it's already in EVE format - keep as-is
+        if "\t" in line:
+            lines.append(line)
+            continue
+
+        # Try to extract item name and quantity from space-separated format
+        # Pattern: "Item Name 123" or "Item Name 1,234" or "Item Name 1.234"
+        # The quantity is always at the end and is numeric (possibly with , or . separators)
+        match = re.match(r"^(.+?)\s+(\d[\d,\.]*)\s*$", line)
+        if match:
+            item_name = match.group(1).strip()
+            quantity = match.group(2).replace(",", "").replace(".", "")
+            lines.append(f"{item_name}\t{quantity}")
+            logger.debug(f"[Janice] Normalized '{line}' -> '{item_name}\\t{quantity}'")
+        else:
+            # No quantity found, assume quantity of 1
+            lines.append(f"{line}\t1")
+            logger.debug(f"[Janice] No quantity found in '{line}', defaulting to 1")
+
+    return "\n".join(lines)
+
+
 class JaniceAPIError(Exception):
     """Custom exception for Janice API errors"""
 
@@ -54,8 +97,29 @@ class JaniceService:
         if not app_settings.AAPAYOUT_JANICE_API_KEY:
             raise JaniceAPIError("Janice API key not configured. " "Please set AAPAYOUT_JANICE_API_KEY in settings.")
 
-        # Check cache first (cache by hash of loot text)
-        cache_key = f"janice_appraisal_{hash(loot_text.strip())}"
+        # Normalize loot text to ensure proper tab-separated format
+        normalized_text = normalize_loot_text(loot_text)
+        logger.debug(f"[Janice] Normalized loot text:\n{normalized_text}")
+
+        # Parse quantities from the normalized input (API doesn't return quantities)
+        input_quantities = {}
+        for line in normalized_text.strip().splitlines():
+            if "\t" in line:
+                parts = line.split("\t", 1)
+                item_name = parts[0].strip()
+                try:
+                    quantity = int(parts[1].strip()) if len(parts) > 1 else 1
+                except ValueError:
+                    quantity = 1
+                # Store by lowercase name for case-insensitive matching
+                input_quantities[item_name.lower()] = {
+                    "original_name": item_name,
+                    "quantity": quantity,
+                }
+        logger.info(f"[Janice] Parsed {len(input_quantities)} items with quantities from input")
+
+        # Check cache first (cache by hash of normalized loot text)
+        cache_key = f"janice_appraisal_{hash(normalized_text)}"
         cached = cache.get(cache_key)
         if cached:
             logger.info("Returning cached Janice appraisal")
@@ -71,18 +135,18 @@ class JaniceService:
 
         try:
             logger.info(
-                f"[Janice] Calling Janice API for {len(loot_text.splitlines())} lines "
+                f"[Janice] Calling Janice API for {len(normalized_text.splitlines())} lines "
                 f"(market: {app_settings.AAPAYOUT_JANICE_MARKET}, "
                 f"price_type: {app_settings.AAPAYOUT_JANICE_PRICE_TYPE})"
             )
-            logger.debug(f"[Janice] API URL: {url}")
-            logger.debug(f"[Janice] Loot text preview: {loot_text[:200]}")
+            logger.info(f"[Janice] API URL: {url}")
+            logger.info(f"[Janice] Sending loot text: {repr(normalized_text[:500])}")
 
             response = requests.post(
                 url,
                 headers=headers,
                 params=params,
-                data=loot_text.encode("utf-8"),
+                data=normalized_text.encode("utf-8"),
                 timeout=app_settings.AAPAYOUT_JANICE_TIMEOUT,
             )
 
@@ -116,6 +180,10 @@ class JaniceService:
                 f"[Janice] Received response with {len(items_data) if isinstance(items_data, list) else 0} items"
             )
 
+            # Log first few items for debugging (helps identify quantity issues)
+            if isinstance(items_data, list) and len(items_data) > 0:
+                logger.info(f"[Janice] Raw API response (first 3 items): {items_data[:3]}")
+
             if not isinstance(items_data, list):
                 logger.error(f"[Janice] Unexpected response format: {type(items_data)}")
                 raise JaniceAPIError("Unexpected API response format")
@@ -131,10 +199,22 @@ class JaniceService:
                 try:
                     type_id = item["itemType"]["eid"]
                     name = item["itemType"]["name"]
-                    quantity = item.get("quantity", 1)
+
+                    # Look up quantity from our parsed input (API doesn't return quantities)
+                    # Match by lowercase name for case-insensitive matching
+                    input_data = input_quantities.get(name.lower())
+                    if input_data:
+                        quantity = input_data["quantity"]
+                    else:
+                        # Item wasn't in our input - this shouldn't happen normally
+                        logger.warning(f"[Janice] Item '{name}' from API response not found in input, defaulting to 1")
+                        quantity = 1
+
                     unit_price = Decimal(str(item["immediatePrices"][price_key]))
                     item_total_value = quantity * unit_price
 
+                    logger.debug(f"[Janice] Item '{name}': qty={quantity}, unit={unit_price}, total={item_total_value}")
+
                     processed_items.append(
                         {
                             "type_id": type_id,
