@@ -19,8 +19,9 @@
         initializeLootTextCounter();
         initializeInlinePaymentActions();
         initializeParticipantStatusToggles();
-        initializeFleetInlineEdit();
         initializeModalAutocomplete();
+        initializeCopyOnClick();
+        initializeScoutBonusSlider();
     });
 
     // ========================================
@@ -372,12 +373,12 @@
             });
         });
 
-        // Mark Paid buttons
-        document.querySelectorAll('.mark-paid-btn').forEach(function (btn) {
+        // Mark Verified buttons (manual override)
+        document.querySelectorAll('.mark-verified-btn').forEach(function (btn) {
             btn.addEventListener('click', function (e) {
                 e.preventDefault();
                 const payoutId = this.dataset.payoutId;
-                markPayoutPaid(payoutId, this);
+                markPayoutVerified(payoutId, this);
             });
         });
     }
@@ -462,19 +463,20 @@
             });
     }
 
-    function markPayoutPaid(payoutId, button) {
-        if (!confirm('Mark this payout as paid?')) {
+    function markPayoutVerified(payoutId, button) {
+        if (!confirm('Mark this payout as verified? This will allow fleet finalization even without ESI verification.')) {
             return;
         }
 
         const csrftoken = getCookie('csrftoken');
-        const row = button.closest('tr');
+        const buttonGroup = button.closest('.btn-group');
+        const badgeContainer = button.closest('div').querySelector('.badge');
         const originalHTML = button.innerHTML;
 
         button.disabled = true;
         button.innerHTML = '<i class="fas fa-spinner fa-spin"></i>';
 
-        fetch('/payout/api/payouts/' + payoutId + '/mark-paid-express/', {
+        fetch('/payout/api/payouts/' + payoutId + '/mark-verified/', {
             method: 'POST',
             headers: {
                 'X-CSRFToken': csrftoken,
@@ -488,42 +490,31 @@
             })
             .then(function (result) {
                 if (result.ok && result.data.success) {
-                    // Replace button group with "Paid" badge
-                    const actionsCell = button.closest('td');
-                    actionsCell.innerHTML = '<span class="badge bg-success"><i class="fas fa-check"></i> Paid</span>';
+                    // Remove the button
+                    button.remove();
 
-                    // Add success styling to row
-                    row.classList.add('table-success');
+                    // Update badge to show verified
+                    if (badgeContainer) {
+                        badgeContainer.className = 'badge bg-success';
+                        badgeContainer.title = 'Manually verified';
+                        badgeContainer.innerHTML = '<i class="fas fa-check-circle"></i> Verified';
+                    }
 
-                    // Show success message (optional)
-                    showNotification('Payment marked as paid!', 'success');
+                    showFeedback(buttonGroup, 'Marked as verified!');
                 } else {
                     button.innerHTML = originalHTML;
                     button.disabled = false;
-                    alert('Failed to mark as paid: ' + (result.data.error || 'Unknown error'));
+                    alert('Failed to mark as verified: ' + (result.data.error || 'Unknown error'));
                 }
             })
             .catch(function (error) {
                 button.innerHTML = originalHTML;
                 button.disabled = false;
-                console.error('Error marking payout as paid:', error);
-                alert('Failed to mark as paid: ' + error.message);
+                console.error('Error marking as verified:', error);
+                alert('Failed to mark as verified: ' + error.message);
             });
     }
 
-    function showNotification(message, type) {
-        // Simple notification (you can replace with Bootstrap toast or similar)
-        const notification = document.createElement('div');
-        notification.className = 'alert alert-' + type + ' position-fixed top-0 start-50 translate-middle-x mt-3';
-        notification.style.zIndex = '9999';
-        notification.textContent = message;
-        document.body.appendChild(notification);
-
-        setTimeout(function () {
-            notification.remove();
-        }, 3000);
-    }
-
     // ========================================
     // Participant Status Toggles (Scout/Exclude)
     // ========================================
@@ -580,44 +571,31 @@
     }
 
     // ========================================
-    // Fleet Inline Edit
+    // Copy on Click
     // ========================================
 
-    function initializeFleetInlineEdit() {
-        const toggleBtn = document.querySelector('.toggle-edit-btn');
-        const saveBtn = document.querySelector('.save-edit-btn');
-        const cancelBtn = document.querySelector('.cancel-edit-btn');
-        const editableFields = document.querySelectorAll('.fleet-editable');
+    function initializeCopyOnClick() {
+        document.querySelectorAll('.copy-on-click').forEach(function (element) {
+            element.addEventListener('click', function () {
+                let textToCopy = this.dataset.copyText;
 
-        if (!toggleBtn || !saveBtn || !cancelBtn) return;
+                // If it's an amount (contains decimal or comma), remove decimals for EVE
+                if (textToCopy && textToCopy.match(/[\d,\.]/)) {
+                    // Remove commas and convert to number, then floor it
+                    const cleanAmount = Math.floor(parseFloat(textToCopy.replace(/,/g, '')));
+                    textToCopy = cleanAmount.toString();
+                }
 
-        // Store original values for cancel functionality
-        const originalValues = {};
-        editableFields.forEach(function (field) {
-            originalValues[field.name] = field.value;
-        });
+                copyToClipboard(textToCopy);
 
-        // Toggle edit mode
-        toggleBtn.addEventListener('click', function () {
-            editableFields.forEach(function (field) {
-                field.readOnly = false;
-                field.classList.add('border-warning');
+                // Visual feedback
+                const originalText = this.innerHTML;
+                this.innerHTML = '<i class="fas fa-check text-success"></i> ' + originalText;
+
+                setTimeout(function () {
+                    element.innerHTML = originalText;
+                }.bind(this), 1000);
             });
-            saveBtn.style.display = 'inline-block';
-            cancelBtn.style.display = 'inline-block';
-            toggleBtn.style.display = 'none';
-        });
-
-        // Cancel edit
-        cancelBtn.addEventListener('click', function () {
-            editableFields.forEach(function (field) {
-                field.value = originalValues[field.name];
-                field.readOnly = true;
-                field.classList.remove('border-warning');
-            });
-            saveBtn.style.display = 'none';
-            cancelBtn.style.display = 'none';
-            toggleBtn.style.display = 'inline-block';
         });
     }
 
@@ -799,3 +777,163 @@ function getCookie(name) {
     }
     return cookieValue;
 }
+
+// ========================================
+// Scout Bonus Slider
+// ========================================
+
+function initializeScoutBonusSlider() {
+    // Fleet detail page slider (with AJAX update)
+    const slider = document.getElementById('scout-bonus-slider');
+    if (slider) {
+        const valueDisplay = document.getElementById('scout-bonus-value');
+        const lootPoolId = slider.dataset.lootPoolId;
+        let updateTimer;
+
+        // Update display as slider moves
+        slider.addEventListener('input', function () {
+            if (valueDisplay) {
+                valueDisplay.textContent = this.value;
+            }
+        });
+
+        // Update server when slider changes (with debounce)
+        slider.addEventListener('change', function () {
+            clearTimeout(updateTimer);
+            const newPercentage = this.value;
+
+            // Show loading state
+            if (valueDisplay) {
+                valueDisplay.textContent = newPercentage + ' (updating...)';
+            }
+
+            updateTimer = setTimeout(function () {
+                updateScoutBonus(lootPoolId, newPercentage, 'scout-bonus-value');
+            }, 300);
+        });
+    }
+
+    // Loot create page slider (client-side display only)
+    const sliderCreate = document.getElementById('scout-bonus-slider-create');
+    if (sliderCreate) {
+        const valueDisplayCreate = document.getElementById('scout-bonus-value-create');
+
+        // Update display as slider moves
+        sliderCreate.addEventListener('input', function () {
+            if (valueDisplayCreate) {
+                valueDisplayCreate.textContent = this.value;
+            }
+        });
+    }
+
+    // Loot detail page slider (with AJAX update)
+    const sliderDetail = document.getElementById('scout-bonus-slider-detail');
+    if (sliderDetail) {
+        const valueDisplayDetail = document.getElementById('scout-bonus-value-detail');
+        const lootPoolIdDetail = sliderDetail.dataset.lootPoolId;
+        let updateTimerDetail;
+
+        // Update display as slider moves
+        sliderDetail.addEventListener('input', function () {
+            if (valueDisplayDetail) {
+                valueDisplayDetail.textContent = this.value;
+            }
+        });
+
+        // Update server when slider changes (with debounce)
+        sliderDetail.addEventListener('change', function () {
+            clearTimeout(updateTimerDetail);
+            const newPercentage = this.value;
+
+            // Show loading state
+            if (valueDisplayDetail) {
+                valueDisplayDetail.textContent = newPercentage + ' (updating...)';
+            }
+
+            updateTimerDetail = setTimeout(function () {
+                updateScoutBonus(lootPoolIdDetail, newPercentage, 'scout-bonus-value-detail');
+            }, 300);
+        });
+    }
+
+    // Loot edit page slider (with AJAX update)
+    const sliderEdit = document.getElementById('scout-bonus-slider-edit');
+    if (sliderEdit) {
+        const valueDisplayEdit = document.getElementById('scout-bonus-value-edit');
+        const lootPoolIdEdit = sliderEdit.dataset.lootPoolId;
+        let updateTimerEdit;
+
+        // Update display as slider moves
+        sliderEdit.addEventListener('input', function () {
+            if (valueDisplayEdit) {
+                valueDisplayEdit.textContent = this.value;
+            }
+        });
+
+        // Update server when slider changes (with debounce)
+        sliderEdit.addEventListener('change', function () {
+            clearTimeout(updateTimerEdit);
+            const newPercentage = this.value;
+
+            // Show loading state
+            if (valueDisplayEdit) {
+                valueDisplayEdit.textContent = newPercentage + ' (updating...)';
+            }
+
+            updateTimerEdit = setTimeout(function () {
+                updateScoutBonus(lootPoolIdEdit, newPercentage, 'scout-bonus-value-edit');
+            }, 300);
+        });
+    }
+}
+
+function updateScoutBonus(lootPoolId, percentage, displayElementId) {
+    const csrftoken = getCookie('csrftoken');
+    // Use provided displayElementId or fallback to default
+    const elementId = displayElementId || 'scout-bonus-value';
+    const valueDisplay = document.getElementById(elementId);
+
+    fetch('/payout/api/loot/' + lootPoolId + '/update-scout-bonus/', {
+        method: 'POST',
+        headers: {
+            'X-CSRFToken': csrftoken,
+            'Content-Type': 'application/json',
+        },
+        body: JSON.stringify({ percentage: percentage }),
+    })
+        .then(function (response) {
+            if (!response.ok) {
+                throw new Error('Failed to update scout bonus');
+            }
+            return response.json();
+        })
+        .then(function (data) {
+            if (data.success) {
+                // Update display
+                if (valueDisplay) {
+                    valueDisplay.textContent = percentage;
+                }
+                showSuccessToast('Scout bonus updated to ' + percentage + '%. Payouts recalculated.');
+
+                // Reload page to show updated payouts
+                setTimeout(function () {
+                    window.location.reload();
+                }, 1000);
+            } else {
+                throw new Error(data.error || 'Update failed');
+            }
+        })
+        .catch(function (error) {
+            console.error('Error updating scout bonus:', error);
+            showErrorToast('Failed to update scout bonus: ' + error.message);
+            // Reset display
+            if (valueDisplay) {
+                // Derive slider ID from display element ID by replacing '-value' with '-slider'
+                const sliderId = elementId.replace('-value', '-slider');
+                const slider = document.getElementById(sliderId);
+                if (slider) {
+                    valueDisplay.textContent = slider.value;
+                }
+            }
+        });
+}
