@@ -18,6 +18,7 @@ from allianceauth.eveonline.models import EveCharacter
 from eveuniverse.models import EveEntity
 
 # AA Payout
+from aapayout import app_settings
 from aapayout.helpers import (
     calculate_payouts,
     deduplicate_participants,
@@ -244,6 +245,12 @@ class CalculatePayoutsWithDeduplicationTest(TestCase):
 
     def setUp(self):
         """Set up test data"""
+        # Patch minimum payout settings for tests
+        self.settings_patcher = patch.object(app_settings, "AAPAYOUT_MINIMUM_PAYOUT", 1000)
+        self.per_participant_patcher = patch.object(app_settings, "AAPAYOUT_MINIMUM_PER_PARTICIPANT", 1000)
+        self.settings_patcher.start()
+        self.per_participant_patcher.start()
+
         # Create test user
         self.user = User.objects.create_user(username="testuser", password="password")
 
@@ -273,6 +280,11 @@ class CalculatePayoutsWithDeduplicationTest(TestCase):
             corp_share_percentage=Decimal("10.00"),
         )
 
+    def tearDown(self):
+        """Stop patching settings"""
+        self.settings_patcher.stop()
+        self.per_participant_patcher.stop()
+
     def test_payout_calculation_with_deduplication(self):
         """Test that payouts use deduplication (one per player)"""
         # Create participants - Player 1 has 2 characters, Player 2 has 1
@@ -374,6 +386,12 @@ class DeduplicationIntegrationTest(TestCase):
 
     def setUp(self):
         """Set up test data"""
+        # Patch minimum payout settings for tests
+        self.settings_patcher = patch.object(app_settings, "AAPAYOUT_MINIMUM_PAYOUT", 1000)
+        self.per_participant_patcher = patch.object(app_settings, "AAPAYOUT_MINIMUM_PER_PARTICIPANT", 1000)
+        self.settings_patcher.start()
+        self.per_participant_patcher.start()
+
         # Create test user
         self.user = User.objects.create_user(username="testuser", password="password")
 
@@ -403,6 +421,11 @@ class DeduplicationIntegrationTest(TestCase):
             fleet_time=timezone.now(),
         )
 
+    def tearDown(self):
+        """Stop patching settings"""
+        self.settings_patcher.stop()
+        self.per_participant_patcher.stop()
+
     def test_multi_boxing_scenario(self):
         """
         Test realistic scenario:
